--
-- CollectParticlesystems
-- Specialization for collector particle systems at forage loaders
--
-- @author  Stefan Maurus	
-- @date  04/06/14

-- Copyright  Stefan Maurus, www.stefanmaurus.de

-- @edit for FS15 06/11/2014

--[[
	<collectParticlesystems>
		<particleSystem type="FRUITTYPE" index="INDEX" file="PATH"/> <!--In INDEX has to be a cutting area (start(INDEX|0), width(INDEX|1), height(INDEX|2))-->
		...
	</collectParticlesystems>	
]]

CollectParticlesystems = {};

function CollectParticlesystems.prerequisitesPresent(specializations)
	return true;
end;

function CollectParticlesystems:load(xmlFile)		
	local i = 0;
	self.collectParticlesystems = {};
	while true do
        local key = string.format("vehicle.collectParticlesystems.particleSystem(%d)", i);
		if not hasXMLProperty(xmlFile, key) then
			break;
		end;
		local index = Utils.indexToObject(self.components, getXMLString(xmlFile, key.."#index"));
		
		local fruitType = getXMLString(xmlFile, key.."#type");
		local startIndex = Utils.indexToObject(self.components, ""..getXMLString(xmlFile, key.."#index").."|0");
		local widthIndex = Utils.indexToObject(self.components, ""..getXMLString(xmlFile, key.."#index").."|1");
		local heightIndex = Utils.indexToObject(self.components, ""..getXMLString(xmlFile, key.."#index").."|2");
		
		local particleSystem = {};
        Utils.loadParticleSystem(xmlFile, particleSystem, key, index, false, nil, self.baseDirectory);
		
		table.insert(self.collectParticlesystems, {fruitType=fruitType, startIndex=startIndex, widthIndex=widthIndex, heightIndex=heightIndex, particleSystem=particleSystem});
		i = i + 1;
	end;
	self.pickupIsDownTemp = self:getAnimationTime(self.pickupAnimationName) == 1;
end;

function CollectParticlesystems:delete()
	for _, ps in pairs(self.collectParticlesystems) do
		Utils.deleteParticleSystem(ps.particleSystem);
	end;
end;

function CollectParticlesystems:mouseEvent(posX, posY, isDown, isUp, button)
end;

function CollectParticlesystems:keyEvent(unicode, sym, modifier, isDown)
end;

function CollectParticlesystems:update(dt)
	if self.isTurnedOn and self.isPickupLowered then
		for _, node in pairs(self.collectParticlesystems) do
			if self.lastSpeed*3600 > 1 and self.movingDirection > 0 and self.fillLevel < self.capacity then
				local x,_,z = getWorldTranslation(node.startIndex);
				local x1,_,z1 = getWorldTranslation(node.widthIndex);
				local x2,_,z2 = getWorldTranslation(node.heightIndex);   
				local area = 0;
				if node.fruitType == "drygrass" then
					area = Utils.getFruitWindrowArea(FruitUtil.FRUITTYPE_DRYGRASS, x, z, x1, z1, x2, z2);
				else
					area = Utils.getFruitWindrowArea(FruitUtil.fillTypeToFruitType[Fillable.fillTypeNameToInt[node.fruitType]], x, z, x1, z1, x2, z2);
				end;

				Utils.setEmittingState(node.particleSystem, area > 0);
			else
				Utils.setEmittingState(node.particleSystem, false);
			end;
		end
	else
		for _, node in pairs(self.collectParticlesystems) do
			Utils.setEmittingState(node.particleSystem, false)	
		end;
	end;
end;

function CollectParticlesystems:updateTick(dt)
 end;

function CollectParticlesystems:onAttach()
end;

function CollectParticlesystems:onDetach()	
end; 

function CollectParticlesystems:draw()
end;